/**
 * Created by following the React Navigation docs.
 * @see https://reactnavigation.org/docs/custom-navigators/
 */
import * as React from 'react';
import { createNavigatorFactory, useNavigationBuilder, TabRouter, TabActions, } from '@react-navigation/core';
function TabsNavigator({ initialRouteName, children, screenOptions, tabBarStyle, contentStyle, }) {
    const { state, navigation, descriptors } = useNavigationBuilder(TabRouter, {
        children,
        screenOptions,
        initialRouteName,
    });
    // console.log(`[TabNavigator] render`);
    return (React.createElement("tabs", { style: { width: "100%", height: "100%", }, selectedIndex: state.index, 
        // onSelectedIndexChange={(args) => {
        //   console.log(`[Tabs.onSelectedIndexChange] ${args.oldValue} -> ${args.value}`);
        // }}
        /**
         * Firing the navigation event upon onSelectedIndexChanged handles both the case of
         * tapping the target TabStripItem and swiping between TabContentItems.
         *
         * There is also onSelectedIndexChange (the Property change event) which fires afterward.
         * I think either work fine; would have to closely inspect the implementation to say more.
         */
        onSelectedIndexChanged: (args) => {
            // console.log(`[Tabs.onSelectedIndexChanged] ${args.oldIndex} -> ${args.newIndex}`);
            const route = state.routes[args.newIndex];
            const event = navigation.emit({
                type: 'tabPress',
                target: route.key,
                canPreventDefault: true,
            });
            // console.log(`[Tabs.onSelectedIndexChanged] emitted event`, event);
            // Can't figure out typings, but defaultPrevented is clearly a populated boolean.
            if (!event.defaultPrevented) {
                navigation.dispatch(Object.assign(Object.assign({}, TabActions.jumpTo(route.name)), { target: state.key }));
            }
        } },
        React.createElement("tabStrip", { nodeRole: "tabStrip" }, state.routes.map(route => {
            const routeOptions = descriptors[route.key].options;
            return (React.createElement("tabStripItem", { key: route.key, nodeRole: "items" },
                React.createElement("label", { nodeRole: "label", style: {} }, routeOptions.title || route.name),
                React.createElement("image", Object.assign({ nodeRole: "image" }, (routeOptions.imageSource ?
                    {
                        imageSource: routeOptions.imageSource
                    } :
                    routeOptions.src ?
                        {
                            src: routeOptions.src
                        } :
                        {}), { style: {} }))));
        })),
        state.routes.map(route => (React.createElement("tabContentItem", { key: route.key, nodeRole: "items" }, descriptors[route.key].render())))));
}
export default createNavigatorFactory(TabsNavigator);
//# sourceMappingURL=tabsNavigatorFactory.js.map